nbxmpp.stringprepare.MappingTableFromFunction

Package nbxmpp :: Module stringprepare :: Class MappingTableFromFunction |
[hide private]
[frames] | no frames]

# Class MappingTableFromFunction

source code

Nested Classes | [hide private]
| __implements__ Interface for character mapping classes

Instance Methods | [hide private]
__init__(self, map_table_function) | source code

Method Details | [hide private]

### __init__(self, map_table_function) (Constructor) | source code